pub struct OwnedGuard<'a> { /* private fields */ }Expand description
A guard that protects objects for it’s lifetime, independent of the current thread.
Unlike LocalGuard, an owned guard is independent of the current thread,
allowing it to implement Send and Sync. This is useful for holding
guards across .await points in work-stealing schedulers, where execution
may be resumed on a different thread than started on. However, owned guards
are more expensive to create and destroy, so should be avoided if
cross-thread usage is not required.
Most of the functionality provided by this type is through the Guard
trait.